hepconvert.merge_root
=====================

Defined in `hepconvert.merge <https://github.com/zbilodea/hepconvert/blob/52e6cbfbbf81c669ca31b8a538d8f3e8984b35a5/src/hepconvert/merge.py>`__ on `line 17 <https://github.com/zbilodea/hepconvert/blob/52e6cbfbbf81c669ca31b8a538d8f3e8984b35a5/src/hepconvert/merge.py#L17>`__.

.. autofunction:: hepconvert.merge_root
